pub struct HttpRecordResolver { /* private fields */ }Expand description
Resolver that fetches records using public XRPC endpoints.
Uses an identity resolver to dynamically determine the PDS endpoint for each record.
Implementations
Sourceimpl HttpRecordResolver
impl HttpRecordResolver
Sourcepub fn new(
http_client: Client,
identity_resolver: Arc<dyn IdentityResolver>,
) -> Self
pub fn new( http_client: Client, identity_resolver: Arc<dyn IdentityResolver>, ) -> Self
Create a new resolver using the provided HTTP client and identity resolver.
The identity resolver is used to dynamically determine the PDS endpoint for each record based on the authority (DID or handle) in the AT URI.